==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fPutstatic.h <==
// class soot.coffi.Instruction_Putstatic

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 535259bc546b8143 soot_coffi_Instruction__5fPutstatic
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fPutstatic_H_
#define _JC_soot_coffi_Instruction__5fPutstatic_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$sub_refs	_jc_soot_coffi_Instruction__5fPutstatic$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs	_jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$refs	_jc_soot_coffi_Instruction__5fPutstatic$refs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$nonrefs	_jc_soot_coffi_Instruction__5fPutstatic$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$object	_jc_soot_coffi_Instruction__5fPutstatic$object;

typedef const struct _jc_soot_coffi_Instruction__5fPutstatic$vmethods	_jc_soot_coffi_Instruction__5fPutstatic$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fPutstatic$vtable	_jc_soot_coffi_Instruction__5fPutstatic$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fPutstatic$vtype	_jc_soot_coffi_Instruction__5fPutstatic$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fPutstatic$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fPutstatic$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fPutstatic$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fPutstatic$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fPutstatic$vmethods	soot_coffi_Instruction__5fPutstatic;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fPutstatic$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fPutstatic$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutstatic$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutstatic$refs {
    _jc_soot_coffi_Instruction__5fPutstatic$sub_refs	soot_coffi_Instruction__5fPutstatic;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutstatic$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs	soot_coffi_Instruction__5fPutstatic;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fPutstatic$object {
	_jc_soot_coffi_Instruction__5fPutstatic$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fPutstatic$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fPutstatic$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fPutstatic$vtype _jc_soot_coffi_Instruction__5fPutstatic$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fPutstatic, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fPutstatic$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fPutstatic_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fPutstatic.h <==
// class soot.coffi.Instruction_Putstatic

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 535259bc546b8143 soot_coffi_Instruction__5fPutstatic
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fPutstatic_H_
#define _JC_soot_coffi_Instruction__5fPutstatic_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$sub_refs	_jc_soot_coffi_Instruction__5fPutstatic$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs	_jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$refs	_jc_soot_coffi_Instruction__5fPutstatic$refs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$nonrefs	_jc_soot_coffi_Instruction__5fPutstatic$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fPutstatic$object	_jc_soot_coffi_Instruction__5fPutstatic$object;

typedef const struct _jc_soot_coffi_Instruction__5fPutstatic$vmethods	_jc_soot_coffi_Instruction__5fPutstatic$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fPutstatic$vtable	_jc_soot_coffi_Instruction__5fPutstatic$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fPutstatic$vtype	_jc_soot_coffi_Instruction__5fPutstatic$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fPutstatic$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fPutstatic$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fPutstatic$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fPutstatic$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fPutstatic$vmethods	soot_coffi_Instruction__5fPutstatic;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fPutstatic$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fPutstatic$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutstatic$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutstatic$refs {
    _jc_soot_coffi_Instruction__5fPutstatic$sub_refs	soot_coffi_Instruction__5fPutstatic;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fPutstatic$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fPutstatic$sub_nonrefs	soot_coffi_Instruction__5fPutstatic;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fPutstatic$object {
	_jc_soot_coffi_Instruction__5fPutstatic$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fPutstatic$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fPutstatic$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fPutstatic$vtype _jc_soot_coffi_Instruction__5fPutstatic$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fPutstatic, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fPutstatic$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fPutstatic_H_ */
